* Analysis for Abouharb and Fordham paper for APSA 2006
* Revisions undertaken in the summer of 2008 with an expanded
* dataset on work stoppages.
* This do file will replication the analysis in Abouharb, M. Rodwan, and Benjamin O. Fordham 2020. 
* "Trade and Strike Activity in the Postwar United States." Social Sciences 9(11), 198. 
* https://www.mdpi.com/2076-0760/9/11/198.

* It should be run on the replication dataset, 'replication.dta' included with this file in the 
* replication archive using Stata 15.1 or later

xtset statecd year

* Levin, Lin, and Chu unit root test for work stoppages and days idle
* Work stoppages, 1947-81
levinlin stoppages if year>=1947 & year<=1981 & statecd<80, lags(5) t
levinlin stoppages if year>=1947 & year<=1981 & statecd<80, lags(8) t
levinlin stoppages if year>=1947 & year<=1981 & statecd<80, lags(10) t
levinlin stoppages if year>=1947 & year<=1981 & statecd<80, lags(15) t

* Work stoppages, 1984-2001
levinlin stoppages if year>=1984 & year<=2001 & statecd<80, lags(5) t
levinlin stoppages if year>=1984 & year<=2001 & statecd<80, lags(8) t
levinlin stoppages if year>=1984 & year<=2001 & statecd<80, lags(10) t
levinlin stoppages if year>=1984 & year<=2001 & statecd<80, lags(15) t

* Days idle, 1947-81
levinlin daysidle1000 if year>=1947 & year<=1981 & statecd<80, lags(5) t
levinlin daysidle1000 if year>=1947 & year<=1981 & statecd<80, lags(8) t
levinlin daysidle1000 if year>=1947 & year<=1981 & statecd<80, lags(10) t
levinlin daysidle1000 if year>=1947 & year<=1981 & statecd<80, lags(15) t

* Days idle, 1984-2001
levinlin daysidle1000 if year>=1984 & year<=2001 & statecd<80, lags(5) t
levinlin daysidle1000 if year>=1984 & year<=2001 & statecd<80, lags(8) t
levinlin daysidle1000 if year>=1984 & year<=2001 & statecd<80, lags(10) t
levinlin daysidle1000 if year>=1984 & year<=2001 & statecd<80, lags(15) t

* Table 1, models with no controls
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty if year>=1947 & year<=1981, nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty if year>=1984 & year<=2001, nolog

* Table 1, models with fixed effects
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty if year>=1947 & year<=1981, fe nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty if year>=1984 & year<=2001, fe nolog

* Table 1, models with control variables
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1947 & year<=1981, nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, nolog

* Table 2, models with no controls
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty if year>=1947 & year<=1981, pairwise
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty if year>=1984 & year<=2001, pairwise

* Table 2, models with fixed effects
xi: xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty i.statecd if year>=1947 & year<=1981, pairwise
xi: xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty i.statecd if year>=1984 & year<=2001, pairwise

* Table 2, models with control variables
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1947 & year<=1981, pairwise
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, pairwise

* Table 3, model with no control variables
xtpcse unionpct unionpct1 msensmfg xintmfg if year>=1964 & year<=2001

* Table 3, model with fixed effects
xi: xtpcse unionpct unionpct1 msensmfg xintmfg i.statecd if year>=1964 & year<=2001

* Table 3, model with control variables
xtpcse unionpct unionpct1 msensmfg xintmfg mfgpct rtwlaw unemp citi6004 inst6002 if year>=1964 & year<=2001

* Levin, Lin, and Chu unit root test for union density
levinlin unionpct, lags(5) t
levinlin unionpct, lags(8) t
levinlin unionpct, lags(10) t
levinlin unionpct, lags(15) t

* Table 4, model with no control variables
xtpcse changeunion changeunion1 dmsensmfg dxintmfg if year>=1964 & year<=2001

* Table 4, model with fixed effects
xi: xtpcse changeunion changeunion1 dmsensmfg dxintmfg i.statecd if year>=1964 & year<=2001

* Table 4, model with control variables
xtpcse changeunion changeunion1 dmsensmfg dxintmfg dmfgpct drtwlaw dunemp dciti6004 dinst6002 if year>=1964 & year<=2001

* Appendices
* Table A1
sum stoppages daysidle msensmfg xintmfg uncertainty unionpct pcpi1000 rtwlaw unemp citi6004 inst6002 wsemployees if year>=1947 & year<=1981
sum stoppages daysidle msensmfg xintmfg uncertainty unionpct pcpi1000 rtwlaw unemp citi6004 inst6002 wsemployees if year>=1984 & year<=2001

* Table A2, logged dependent variable
xtpcse lndaysidle1000 lndaysidle10001 lnworkforce msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1947 & year<=1981, pairwise
xtpcse lndaysidle1000 lndaysidle10001 lnworkforce msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, pairwise

* Table A2, tobit model of days lost to work stoppages
xttobit daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, ll(0) nolog

* Table A2, tobit model of logged days lost to work stoppages
xttobit lndaysidle1000 lndaysidle10001 lnworkforce msensmfg xintmfg uncertainty unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, ll(0) nolog

* Table A3, models with no control variables
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd if year>=1947 & year<=1981, nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd if year>=1984 & year<=2001, nolog

* Table A3, models with fixed effects
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd if year>=1947 & year<=1981, fe nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd if year>=1984 & year<=2001, fe nolog

* Table A3, model with control variables
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1947 & year<=1981, nolog
xtnbreg stoppages stoppages1 i_wsemployeesmill msensmfg xintmfg uncertainty_sd unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, nolog

* Table A4, models with no control variables
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd if year>=1947 & year<=1981, pairwise
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd if year>=1984 & year<=2001, pairwise

* Table A4, models with fixed effects
xi: xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd i.statecd if year>=1947 & year<=1981, pairwise
xi: xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd i.statecd if year>=1984 & year<=2001, pairwise

* Table A4, model with control variables
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1947 & year<=1981, pairwise
xtpcse daysidle1000 daysidle10001 i_wsemployees1000 msensmfg xintmfg uncertainty_sd unionpct unionpct_sq pcpi1000 rtwlaw unemp citi6004 inst6002 if year>=1984 & year<=2001, pairwise


